============
Contributors
============


How to contribute?
------------------

* Check for open issues or open a fresh issue to start a discussion around a feature idea or a bug.
* Fork https://github.com/django-leonardo/django-leonardo.git on GitHub to start making your changes to the **develop** branch.
* Write a test which shows that the bug was fixed or that the feature works as expected.
* Make sure to add yourself to the :ref:`contributors`.
* Send a pull request

You can help further the development of **django-leonardo** by reporting bugs, submitting documentation, patches, with monetary or hardware donations.

Lead developers
--------------
* Aleš Komárek (mail@newt.cz) <newt.cz>
* Michael Kutý (mail@majklk.cz) <majklk.cz>

Contributors (in alphabetical order)
------------------------------------

* No contribution